package com.ruoyi.voluntary.mapper;

import java.util.List;
import com.ruoyi.voluntary.domain.BusiClasses;

/**
 * 班级Mapper接口
 * 
 * @author voluntary
 * @date 2022-11-20
 */
public interface BusiClassesMapper 
{
    /**
     * 查询班级
     * 
     * @param classId 班级主键
     * @return 班级
     */
    public BusiClasses selectBusiClassesByClassId(Long classId);

    /**
     * 查询班级列表
     * 
     * @param busiClasses 班级
     * @return 班级集合
     */
    public List<BusiClasses> selectBusiClassesList(BusiClasses busiClasses);

    /**
     * 新增班级
     * 
     * @param busiClasses 班级
     * @return 结果
     */
    public int insertBusiClasses(BusiClasses busiClasses);

    /**
     * 修改班级
     * 
     * @param busiClasses 班级
     * @return 结果
     */
    public int updateBusiClasses(BusiClasses busiClasses);

    /**
     * 删除班级
     * 
     * @param classId 班级主键
     * @return 结果
     */
    public int deleteBusiClassesByClassId(Long classId);

    /**
     * 批量删除班级
     * 
     * @param classIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusiClassesByClassIds(Long[] classIds);
}
